.. Yandex 360 Lib documentation master file, created by
   sphinx-quickstart on Tue Jul 26 13:44:05 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. meta::
   :yandex-verification: 71fab5bb44d088d6

Документация yandex_360
=======================

   Библиотека функций для работы с Яндекс 360 API

.. toctree::
   :maxdepth: 3
   :caption: Содержание

   usage
   yandex_360

.. toctree::
   :maxdepth: 3
   :caption: Предметный указатель

   glossary

.. toctree::
   :maxdepth: 3
   :caption: Лицензирование

   lic

* :ref:`genindex`
* :ref:`modindex`